package com.zy.omp.common.redis;

import com.alibaba.fastjson.JSON;
import com.zy.omp.common.Constant;
import com.zy.omp.model.Admin;
import com.zy.omp.utils.CodeGenerator;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.concurrent.TimeUnit;

/**
 * 用户登录Session
 *
 * @author chenyi
 * Create on 2020/4/3
 */
@Component
public class SessionManager {

    @Resource
    private StringRedisTemplate stringRedisTemplate;

    /**
     * 生成token
     */
    public String generateToken(Admin admin) {
        String token = CodeGenerator.generateUUID();
        stringRedisTemplate.opsForValue()
                .set(Constant.REDIS_TOKEN_PREFIX + token, JSON.toJSONString(admin), 30, TimeUnit.MINUTES);
        return token;
    }

    /**
     * 删除Token
     */
    public void removeToken(String token) {
        if (token == null) return;
        stringRedisTemplate.delete(Constant.REDIS_TOKEN_PREFIX + token);
    }

    /**
     * 获取登录的用户信息
     */
    public Admin getUser(String token) {
        if (token == null) return null;
        return JSON.parseObject(stringRedisTemplate.opsForValue().get(Constant.REDIS_TOKEN_PREFIX + token), Admin.class);
    }

    /**
     * 验证token有效
     */
    public boolean valid(String token) {
        if (token == null || getUser(token) == null) return false;
        stringRedisTemplate.expire(Constant.REDIS_TOKEN_PREFIX + token, 30, TimeUnit.MINUTES);
        return true;
    }
}
