package com.zy.omp.controller.wx;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.zy.omp.common.ServerResponse;
import com.zy.omp.common.controller.BaseController;
import com.zy.omp.model.DeviceDynamic;
import com.zy.omp.service.DeviceService;
import com.zy.omp.service.DeviceDynamicService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 用户设备绑定关系
 *
 * @author chen_yi
 * Create on 2020/8/1
 */
@RestController
@RequestMapping("omp/api/wx/device")
public class DeviceController extends BaseController {

    @Resource
    private DeviceDynamicService deviceDynamicService;

    @Resource
    private DeviceService deviceService;

    /**
     * 更新设备名称
     *
     * @param num  设备随机 num
     * @param name 设备名称
     */
    @PostMapping("updateName.do")
    public ServerResponse updateName(String num, String name) {
        deviceDynamicService.updateName(getUserId(), num, name);
        return ServerResponse.createBySuccess();
    }

    /**
     * 添加绑定关系
     */
    @PostMapping("bind.do")
    public ServerResponse bind(DeviceDynamic entity) {
        if (deviceService.getByNum(entity.getDeviceNum()) == null)
            return ServerResponse.createByWarning("无效设备码!");
        if (deviceDynamicService.checkBind(entity.getDeviceNum()))
            return ServerResponse.createByWarning("该设备已经有用户绑定!");
        entity.setUserId(getUserId());
        deviceDynamicService.save(entity);
        return ServerResponse.createBySuccess();
    }

    /**
     * 解除绑定关系
     */
    @PostMapping("unbind.do")
    public ServerResponse unbind(String deviceNum) {
        deviceDynamicService.unbind(deviceNum, getUserId());
        return ServerResponse.createBySuccess();
    }

    /**
     * 查询用户的所有设备
     */
    @GetMapping("getListByUserId.do")
    public ServerResponse getListByUserId() {
        QueryWrapper<DeviceDynamic> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("userId", getUserId());
        queryWrapper.orderByDesc("isDefault");
        return ServerResponse.createBySuccess(deviceDynamicService.list(queryWrapper));
    }

    /**
     * 修改默认设备
     * 即登陆以后使用那个设备
     *
     * @param deviceNum 设备码
     */
    @PostMapping("changeDefault.do")
    public ServerResponse changeDefault(String deviceNum) {
        //删除上一个默认设备
        deviceDynamicService.update(Wrappers.<DeviceDynamic>lambdaUpdate().eq(DeviceDynamic::getIsDefault, 1)
                .eq(DeviceDynamic::getUserId, getUserId()).set(DeviceDynamic::getIsDefault, 0));
        //添加新的默认设备
        deviceDynamicService.update(Wrappers.<DeviceDynamic>lambdaUpdate().eq(DeviceDynamic::getDeviceNum, deviceNum)
                .set(DeviceDynamic::getIsDefault, 1));
        return ServerResponse.createBySuccess();
    }
}
