package com.zy.omp.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zy.omp.mapper.DeviceDynamicMapper;
import com.zy.omp.model.DeviceDynamic;
import org.springframework.stereotype.Service;

/**
 * 用户设备绑定关系Service
 *
 * @author chenyi
 * Create on 2020/4/10
 */
@Service
public class DeviceDynamicService extends ServiceImpl<DeviceDynamicMapper, DeviceDynamic> {

    /**
     * 通过设备号删除绑定关系
     *
     * @param deviceNum 设备号
     */
    public void unbind(String deviceNum, String userId) {
        QueryWrapper<DeviceDynamic> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("deviceNum", deviceNum);
        queryWrapper.eq("userId", userId);
        baseMapper.delete(queryWrapper);
    }

    /**
     * 查询设备是否有绑定关系
     *
     * @param deviceNum 设备号
     */
    public boolean checkBind(String deviceNum) {
        return baseMapper.checkBind(deviceNum) > 0;
    }

    /**
     * 查询设备是否属于该用户
     *
     * @param userId    用户ID
     * @param deviceNum 设备码
     */
    public void updateName(String userId, String deviceNum, String newName) {
        UpdateWrapper<DeviceDynamic> updateWrapper = new UpdateWrapper<>();
        updateWrapper.set("name", newName).eq("userId", userId).eq("deviceNum", deviceNum);
        update(updateWrapper);
    }

    /**
     * 查询设备是否属于该用户
     *
     * @param userId   用户ID
     * @param deviceId 设备ID
     */
    public boolean checkBelong(String userId, String deviceId) {
        return baseMapper.checkBelong(userId, deviceId) > 0;
    }
}
